summaryrefslogtreecommitdiffstats
path: root/include/libiphone/libiphone.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/libiphone/libiphone.h')
-rw-r--r--include/libiphone/libiphone.h11
1 files changed, 10 insertions, 1 deletions
diff --git a/include/libiphone/libiphone.h b/include/libiphone/libiphone.h
index 59d2de2..6197923 100644
--- a/include/libiphone/libiphone.h
+++ b/include/libiphone/libiphone.h
@@ -81,8 +81,17 @@ typedef struct iphone_afc_file_int *iphone_afc_file_t;
struct iphone_msync_client_int;
typedef struct iphone_msync_client_int *iphone_msync_client_t;
-//device related functions
+//debug related functions
+#define DBGMASK_ALL 0xFFFF
+#define DBGMASK_NONE 0x0000
+#define DBGMASK_USBMUX (1 << 1)
+#define DBGMASK_LOCKDOWND (1 << 2)
+#define DBGMASK_MOBILESYNC (1 << 3)
+
+void iphone_set_debug_mask(uint16_t mask);
void iphone_set_debug(int level);
+
+//device related functions
iphone_error_t iphone_get_device ( iphone_device_t *device );
iphone_error_t iphone_free_device ( iphone_device_t device );